@@ -1,6 +1,7 @@
 # This file is part of Tryton & Nereid. The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import ModelSQL, fields
+from trytond.pool import Pool
 
 
 class TestModel(ModelSQL):
@@ -18,3 +19,13 @@ class TestModel(ModelSQL):
         from trytond import backend
         DatabaseOperationalError = backend.get('DatabaseOperationalError')
         raise DatabaseOperationalError()
+
+    @classmethod
+    def test_lazy_renderer(cls):
+        """
+        Just call the home method and modify the headers in the return value
+        """
+        rv = Pool().get('nereid.website').home()
+        rv.headers['X-Test-Header'] = 'TestValue'
+        rv.status = 201
+        return rv
